<?php

namespace Drupal\consent_support\Preprocessor;

use Drupal\consent_support\Config\ConfigManager;
use Drupal\consent_support\Plugin\ConsentSupportPluginManager;
use Drupal\Core\Entity\Display\EntityViewDisplayInterface;
use Drupal\Core\Entity\FieldableEntityInterface;

/**
 * Preprocessor.
 *
 * Default implementation for PreprocessorInterface.
 */
class Preprocessor implements PreprocessorInterface {

  /**
   * The plugin manager.
   *
   * @var \Drupal\consent_support\Plugin\ConsentSupportPluginManager
   */
  protected $entityPluginManager;

  /**
   * The config manager.
   *
   * @var \Drupal\consent_support\Config\ConfigManager
   */
  protected $configManager;

  /**
   * Constructor.
   *
   * @param \Drupal\consent_support\Plugin\ConsentSupportPluginManager $plugin_manager
   *   The plugin manager.
   * @param \Drupal\consent_support\Config\ConfigManager $config_manager
   *   The config manager.
   */
  public function __construct(ConsentSupportPluginManager $plugin_manager, ConfigManager $config_manager) {
    $this->entityPluginManager = $plugin_manager;
    $this->configManager = $config_manager;
  }

  /**
   * {@inheritdoc}
   */
  public function prepareExtendedSupport(array &$build, FieldableEntityInterface $entity, EntityViewDisplayInterface $display): void {

    if (in_array($entity->getEntityTypeId(), $this->entityPluginManager->loadSupportedEntityTypeIds())) {

      /** @var \Drupal\consent_support\Entity\ConfigInterface $config */
      $config = $this->configManager->loadConsentSupportConfig($entity);
      if ($config->getEnabled() || $config->getForceCategory()) {

        $plugin = $this->entityPluginManager->createInstance("consent_support_{$entity->getEntityTypeId()}");
        $plugin->processDisplay($build, $entity, $display, $config);
      }
    }
  }

}
